@@ -262,6 +262,32 @@ def _request_frontend_specific_config(frontend: str,
         _abort_on_None(value)
         conf['xai_model'] = value
 
+    # nvidia part
+    if frontend == 'nvidia' and 'nvidia_base_url' not in current_config:
+        value = SingleEdit(
+            "DebGPT Configurator", "Enter the NVIDIA NIM/NeMo service url:",
+            default['nvidia_base_url'],
+            "Default is https://integrate.api.nvidia.com/v1",
+            "Press Enter to confirm. Press Esc to abort.").run()
+        _abort_on_None(value)
+        conf['nvidia_base_url'] = value
+    if frontend == 'nvidia' and 'nvidia_api_key' not in current_config:
+        value = SingleEdit(
+            "DebGPT Configurator", "Enter the NVIDIA NIM/NeMo API key:",
+            default['nvidia_api_key'],
+            "Typically found here: https://build.nvidia.com/explore/discover",
+            "Press Enter to confirm. Press Esc to abort.").run()
+        _abort_on_None(value)
+        conf['nvidia_api_key'] = value
+    if frontend == 'nvidia' and not is_embedding and 'nvidia_model' not in current_config:
+        value = SingleEdit(
+            "DebGPT Configurator", "Enter the NVIDIA NIM/NeMo model name:",
+            default['nvidia_model'],
+            "If not sure, just keep the default. Available options: https://build.nvidia.com/explore/discover",
+            "Press Enter to confirm. Press Esc to abort.").run()
+        _abort_on_None(value)
+        conf['nvidia_model'] = value
+
     # ollama part
     if frontend == 'ollama' and 'ollama_base_url' not in current_config:
         value = SingleEdit(
@@ -280,6 +306,44 @@ def _request_frontend_specific_config(frontend: str,
         _abort_on_None(value)
         conf['ollama_model'] = value
 
+    # llamacpp part
+    if frontend == 'llamacpp' and 'llamacpp_base_url' not in current_config:
+        value = SingleEdit(
+            "DebGPT Configurator", "Enter the llama-server (llama.cpp) service url:",
+            default['llamacpp_base_url'],
+            "Reference: https://github.com/ggerganov/llama.cpp/blob/master/examples/server/README.md",
+            "Press Enter to confirm. Press Esc to abort.").run()
+        _abort_on_None(value)
+        conf['llamacpp_base_url'] = value
+
+    # deepseek part
+    if frontend == 'deepseek' and 'deepseek_base_url' not in current_config:
+        value = SingleEdit(
+            "DebGPT Configurator", "Enter the DeepSeek service url:",
+            default['deepseek_base_url'],
+            "Just keep the default if you intend to use DeepSeek API service. Reference: https://api-docs.deepseek.com/",
+            "Press Enter to confirm. Press Esc to abort.").run()
+        _abort_on_None(value)
+        conf['deepseek_base_url'] = value
+
+    if frontend == 'deepseek' and 'deepseek_api_key' not in current_config:
+        value = SingleEdit(
+            "DebGPT Configurator", "Enter the DeepSeek API key:",
+            default['deepseek_api_key'],
+            "Typically found here: https://platform.deepseek.com/api_keys",
+            "Press Enter to confirm. Press Esc to abort.").run()
+        _abort_on_None(value)
+        conf['deepseek_api_key'] = value
+
+    if frontend == 'deepseek' and 'deepseek_model' not in current_config:
+        value = SingleEdit(
+            "DebGPT Configurator", "Enter the DeepSeek model name:",
+            default['deepseek_model'],
+            "If not sure, just keep the default. As of Jan 24 2025, the available models are: deepseek-chat, deepseek-reasoner. The list of latest models can be found here: https://api-docs.deepseek.com/quick_start/pricing",
+            "Press Enter to confirm. Press Esc to abort.").run()
+        _abort_on_None(value)
+        conf['deepseek_model'] = value
+
     # llamafile part
     if frontend == 'llamafile' and 'llamafile_base_url' not in current_config:
         value = SingleEdit(
@@ -407,7 +471,10 @@ def fresh_install_guide(dest: Optional[str] = None) -> dict:
         'Anthropic (Claude) | commercial,  Anthropic-API',
         'Google    (Gemini) | commercial,  Google-API',
         'xAI       (Grok)   | commercial,  OpenAI-API',
+        'Nvidia    (*)      | commercial,  OpenAI-API', 
+        'DeepSeek           | commercial,  OpenAI-API, MIT-Licensed Model',
         'Ollama    (*)      | self-hosted, OpenAI-API',
+        'llama.cpp (*)      | self-hosted, OpenAI-API',
         'LlamaFile (*)      | self-hosted, OpenAI-API',
         'vLLM      (*)      | self-hosted, OpenAI-API',
         'ZMQ       (*)      | self-hosted, DebGPT built-in',
@@ -418,11 +485,14 @@ def fresh_install_guide(dest: Optional[str] = None) -> dict:
         'anthropic': 1,
         'google': 2,
         'xai': 3,
-        'ollama': 4,
-        'llamafile': 5,
-        'vllm': 6,
-        'zmq': 7,
-        'dryrun': 8,
+        'nvidia': 4,
+        'deepseek': 5,
+        'ollama': 6,
+        'llamacpp': 7,
+        'llamafile': 8,
+        'vllm': 9,
+        'zmq': 10,
+        'dryrun': 11,
     }[default['frontend']]
 
     frontend = SingleChoice("DebGPT Configurator",
@@ -444,7 +514,7 @@ using the `--frontend|-F` argument.",
                             "Press Enter to confirm. Press Esc to abort.",
                             focus=frontends_focus).run()
     _abort_on_None(frontend)
-    frontend = frontend.split(' ')[0].lower()
+    frontend = frontend.split(' ')[0].lower().replace('.', '')
     conf['frontend'] = frontend
 
     # step 2: ask for the frontend-specific configuration
