@@ -27,11 +27,14 @@ import shlex
 from prompt_toolkit import PromptSession
 from prompt_toolkit.completion import Completer, Completion
 from prompt_toolkit.styles import Style
-from rich.console import Console
+from rich.console import Console, Group
 from rich.live import Live
 from rich.status import Status
 from rich.markdown import Markdown
 from rich.markup import escape
+from rich.text import Text
+from rich.padding import Padding
+from rich.style import Style as richStyle
 
 from . import defaults
 
@@ -158,6 +161,13 @@ class AbstractFrontend():
             json.dump(self.session, f, indent=2)
         console.log(f'{self.NAME}> Conversation saved at {fpath}')
 
+    def __len__(self):
+        '''
+        Calculate the number of messages from user and assistant in the session,
+        excluding system message.
+        '''
+        return len([x for x in self.session if x['role'] != 'system'])
+
 
 class EchoFrontend(AbstractFrontend):
     '''
@@ -252,15 +262,29 @@ class OpenAIFrontend(AbstractFrontend):
                                                          stream=self.stream,
                                                          **self.kwargs)
         if self.stream:
-            chunks = []
+            think, chunks = [], []
+            cursor = chunks
             if self.render_markdown:
                 with Live(Markdown('')) as live:
                     for chunk in completion:
                         if chunk.choices[0].delta.content is None:
                             continue
                         piece = chunk.choices[0].delta.content
-                        chunks.append(piece)
-                        live.update(Markdown(''.join(chunks)), refresh=True)
+                        if piece == '</think>' and think is not None:
+                            cursor = chunks
+                        elif piece == '<think>':
+                            cursor = think
+                        else:
+                            cursor.append(piece)
+                        # join chunks
+                        buffer_think = ''.join(think)
+                        part1 = Text(buffer_think)
+                        part1 = Padding(part1, (0, 2),
+                                        style=richStyle(dim=True, italic=True))
+                        buffer_chunk = ''.join(chunks)
+                        part2 = Markdown(buffer_chunk)
+                        group = Group(part1, part2)
+                        live.update(group, refresh=True)
             else:
                 for chunk in completion:
                     if chunk.choices[0].delta.content is None:
@@ -464,6 +488,26 @@ class XAIFrontend(OpenAIFrontend):
                         f'temperature={args.temperature}, top_p={args.top_p}.')
 
 
+class NvidiaFrontend(OpenAIFrontend):
+    '''
+    This is a frontend for Nvidia's NIM/NeMo service.
+    https://build.nvidia.com/
+    '''
+    NAME = 'Nvidia-Frontend'
+
+    def __init__(self, args):
+        super().__init__(args)
+        from openai import OpenAI
+        self.client = OpenAI(api_key=args.nvidia_api_key,
+                             base_url=args.nvidia_base_url)
+        self.session.append({"role": "system", "content": self.system_message})
+        self.model = args.nvidia_model
+        self.kwargs = {'temperature': args.temperature, 'top_p': args.top_p}
+        if args.verbose:
+            console.log(f'{self.NAME}> model={repr(self.model)}, ' +
+                        f'temperature={args.temperature}, top_p={args.top_p}.')
+
+
 class LlamafileFrontend(OpenAIFrontend):
     '''
     https://github.com/Mozilla-Ocho/llamafile
@@ -502,6 +546,47 @@ class OllamaFrontend(OpenAIFrontend):
                         f'temperature={args.temperature}, top_p={args.top_p}.')
 
 
+class LlamacppFrontend(OpenAIFrontend):
+    '''
+    https://github.com/ggerganov/llama.cpp/blob/master/examples/server/README.md
+    '''
+    NAME = 'LlamacppFrontend'
+
+    def __init__(self, args):
+        AbstractFrontend.__init__(self, args)
+        from openai import OpenAI
+        self.client = OpenAI(api_key='no-key-required',
+                             base_url=args.llamacpp_base_url)
+        self.session.append({"role": "system", "content": self.system_message})
+        self.model = 'model-is-specified-at-the-llama-server-arguments'
+        self.kwargs = {'temperature': args.temperature, 'top_p': args.top_p}
+        if args.verbose:
+            console.log(f'{self.NAME}> ' +
+                        f'temperature={args.temperature}, top_p={args.top_p}.')
+
+
+class DeepSeekFrontend(OpenAIFrontend):
+    '''
+    https://api-docs.deepseek.com/
+    '''
+    NAME = 'DeepSeekFrontend'
+
+    def __init__(self, args):
+        AbstractFrontend.__init__(self, args)
+        from openai import OpenAI
+        self.client = OpenAI(api_key=args.deepseek_api_key,
+                             base_url=args.deepseek_base_url)
+        if args.deepseek_model not in ('deepseek-reasoner'):
+            # see the usage recommendations at
+            # https://huggingface.co/deepseek-ai/DeepSeek-R1
+            self.session.append({"role": "system", "content": self.system_message})
+        self.model = args.deepseek_model
+        self.kwargs = {'temperature': args.temperature, 'top_p': args.top_p}
+        if args.verbose:
+            console.log(f'{self.NAME}> model={repr(self.model)}, ' +
+                        f'temperature={args.temperature}, top_p={args.top_p}.')
+
+
 class vLLMFrontend(OpenAIFrontend):
     '''
     https://docs.vllm.ai/en/stable/serving/openai_compatible_server.html
@@ -598,10 +683,16 @@ def create_frontend(args):
         frontend = GoogleFrontend(args)
     elif args.frontend == 'xai':
         frontend = XAIFrontend(args)
+    elif args.frontend == 'nvidia':
+        frontend = NvidiaFrontend(args)
     elif args.frontend == 'llamafile':
         frontend = LlamafileFrontend(args)
     elif args.frontend == 'ollama':
         frontend = OllamaFrontend(args)
+    elif args.frontend == 'llamacpp':
+        frontend = LlamacppFrontend(args)
+    elif args.frontend == 'deepseek':
+        frontend = DeepSeekFrontend(args)
     elif args.frontend == 'vllm':
         frontend = vLLMFrontend(args)
     elif args.frontend == 'dryrun':
@@ -624,10 +715,10 @@ def interact_once(f: AbstractFrontend, text: str) -> None:
     if f.stream:
         end = '' if not f.render_markdown else '\n'
         if f.monochrome:
-            lprompt = escape(f'LLM[{1+len(f.session)}]> ')
+            lprompt = escape(f'LLM[{2+len(f)}]> ')
             console.print(lprompt, end=end, highlight=False, markup=False)
         else:
-            lprompt = f'[bold green]LLM[{1+len(f.session)}]>[/bold green] '
+            lprompt = f'[bold green]LLM[{2+len(f)}]>[/bold green] '
             console.print(lprompt, end=end)
         _ = f(text)
     else:
@@ -675,7 +766,7 @@ def interact_with(f: AbstractFrontend) -> None:
     user = get_username()
     try:
         while text := prompt_session.prompt(
-                f'{user}[{max(1, len(f.session))}]> '):
+                f'{user}[{1+len(f)}]> '):
             # parse escaped interaction commands
             if text.startswith('/'):
                 cmd = shlex.split(text)
